@@ -1,14 +1,14 @@
 ;;; kixtart-mode.el --- Major mode for editing KiXtart scripts -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2022-2025 Morgan Willcock
+;; Copyright (C) 2022-2026 Morgan Willcock
 
 ;; Author: Morgan Willcock <morgan@ice9.digital>
 ;; Keywords: languages
 ;; Maintainer: Morgan Willcock <morgan@ice9.digital>
 ;; Package-Requires: ((emacs "28.1") (eldoc "1.14.0"))
 ;; URL: https://git.sr.ht/~mew/kixtart-mode
-;; Package-Version: 20251011.1421
-;; Package-Revision: f1a713f812af
+;; Package-Version: 20260115.1810
+;; Package-Revision: a09f91c6dda7
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -496,7 +496,8 @@ declares variables."
 A non-nil value indicates that block motion commands are
 permitted to push the previous location to the `mark-ring' when
 the value of point changes."
-  :type 'boolean)
+  :type 'boolean
+  :safe #'booleanp)
 
 (defun kixtart-beginning-of-defun (&optional arg)
   "Move backwards to the beginning of a function definition.
@@ -568,7 +569,8 @@ of point is modified."
 
 Lines determined to be within script-blocks are indented by this
 number of columns per script-block level."
-  :type 'integer)
+  :type 'integer
+  :safe #'integerp)
 
 (defun kixtart--new-indent ()
   "Return the calculated indentation level for the current line."
@@ -654,12 +656,13 @@ new indentation column."
 
 (defcustom kixtart-align-rules-list
   `((kixtart-assignment
-     (regexp   . ,(kixtart-rx (seq variable
-                                   (group (0+ whitespace))
-                                   "="
-                                   (group (0+ whitespace)))))
-     (group    . (1 2))
-     (tab-stop . nil)))
+     (regexp     . ,(kixtart-rx (seq variable
+                                     (group (0+ whitespace))
+                                     "="
+                                     (group (0+ whitespace)))))
+     (group     . (1 2))
+     (case-fold . t)
+     (tab-stop  . nil)))
   "Specifies the list of available alignment rules.
 
 See the variable `align-rules-list' for details on the list
@@ -911,7 +914,8 @@ function name when point is outside of a function.  When the
 value is set to nil, the name used when point is outside of a
 function will only be determined by `which-function-mode'."
   :type '(choice (string :tag "Default function name")
-                 (const :tag "Let `which-function-mode' decide" nil)))
+                 (const :tag "Let `which-function-mode' decide" nil))
+  :safe (lambda (x) (or (null x) (stringp x))))
 
 (defun kixtart-which-function ()
   "Return the function name which surrounds point.
@@ -941,7 +945,8 @@ structures compatible with the generic method
 
 Where a documentation search returns multiple matches, the
 results will be displayed using this string as the separator."
-  :type 'string)
+  :type 'string
+  :safe #'stringp)
 
 (defcustom kixtart-eldoc-echo-truncate t
   "Specifies how `eldoc-mode' will use the echo area.
@@ -954,7 +959,8 @@ Note that ElDoc version 1.14.0 or newer is required for this
 option to work correctly."
   :type '(choice (const :tag "Never" nil)
                  (natnum :tag "After number of characters")
-                 (const :tag "At end of paragraph" t)))
+                 (const :tag "At end of paragraph" t))
+  :safe (lambda (x) (or (booleanp x) (natnump x))))
 
 (cl-defstruct (kixtart-doc-symbol
                (:constructor nil)
@@ -1186,7 +1192,8 @@ documentation structures."
 
 (defcustom kixtart-completion-case-fold nil
   "Specifies that KiXtart completion should be case-insensitive."
-  :type 'boolean)
+  :type 'boolean
+  :safe #'booleanp)
 
 (defcustom kixtart-completion-list-hook
   (list #'kixtart-completion-upcase-macros
@@ -1318,7 +1325,8 @@ Using a negative argument to move backwards is not supported."
 
 (defcustom kixtart-imenu-submenu-prefix "/"
   "Specifies the string prefix used for Imenu submenu names."
-  :type 'string)
+  :type 'string
+  :safe #'stringp)
 
 (defun kixtart--convert-imenu-item-to-markers (item)
   "Modify ITEM to use markers instead of buffer positions."
@@ -1435,12 +1443,9 @@ be used as part of abbrev expansion."
   "Optionally insert prompt data for NAME using TEMPLATE.
 
 The template is only returned if the data lookup for NAME does
-not return the empty string.  TEMPLATE will have its `p' symbols
-removed when template insertion is interactive."
-  (unless (string= "" (tempo-lookup-named name))
-    (cons 'l (if tempo-interactive
-                 (remove 'p template)
-               template))))
+not return the empty string."
+  (and (not (string= "" (tempo-lookup-named name)))
+       (cons 'l template)))
 
 (defvar kixtart-tempo-tags nil
   "Tempo tags for KiXtart Mode.")
@@ -1505,7 +1510,7 @@ which will be expanded to the template."
     "function"
     "Insert a KiXtart Function definition."
   ("Function " (p "name: " name) (p "arguments: " args 'noinsert)
-   (kixtart--tempo-insert-lookup 'args '("(" (s args) p ")" )) > n
+   (kixtart--tempo-insert-lookup 'args '("(" (s args) ")" )) > n
    > r> n o
    "EndFunction" > (kixtart--tempo-newline-eob)))
 
@@ -1524,7 +1529,7 @@ which will be expanded to the template."
    " = "
    (p "start-expression: " start) " To " (p "end-expression: " end)
    (p "step-size: " step 'noinsert)
-   (kixtart--tempo-insert-lookup 'step '(" Step " (s step) p)) > n
+   (kixtart--tempo-insert-lookup 'step '(" Step " (s step))) > n
    > r> n o
    "Next" > (kixtart--tempo-newline-eob)))
 
@@ -1602,9 +1607,8 @@ which will be expanded to the template."
                collect (vector
                         (concat "Insert " tempo-tag)
                         tempo-function
-                        ':help
-                        (format "Insert the template for Tempo tag \"%s\""
-                                tempo-tag))))
+                        :help (format "Insert the template for Tempo tag \"%s\""
+                                      tempo-tag))))
     "---"
     ["Eval buffer" kixtart-eval-buffer
      :help "Evaluate the buffer contents using the KiXtart interpreter"]
